#
# spec file for package ModemManager
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _udevdir %(pkg-config --variable udevdir udev)
Name:           ModemManager
Version:        1.4.14
Release:        3.3
Summary:        DBus interface for modem handling
License:        GPL-2.0+ and GPL-3.0+
Group:          Productivity/Networking/System
Url:            http://cgit.freedesktop.org/ModemManager/ModemManager
Source0:        http://www.freedesktop.org/software/%{name}/%{name}-%{version}.tar.xz
# PATCH-FIX-OPENSUSE ModemManager-1.0.0-systemd-activation.patch bnc#892682 lnussel@suse.de -- Fix systemd dbus activation
Patch0:         ModemManager-1.0.0-systemd-activation.patch
BuildRequires:  dbus-1-glib-devel
BuildRequires:  gobject-introspection-devel >= 0.9.6
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool >= 0.40.0
BuildRequires:  libgudev-1_0-devel
BuildRequires:  ppp-devel
BuildRequires:  vala-devel >= 0.18
BuildRequires:  pkgconfig(gudev-1.0) >= 147
BuildRequires:  pkgconfig(mbim-glib) >= 1.10
BuildRequires:  pkgconfig(polkit-gobject-1) >= 0.97
BuildRequires:  pkgconfig(qmi-glib) >= 1.12.4
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(udev)
Requires:       hicolor-icon-theme
Recommends:     usb_modeswitch
Provides:       org.freedesktop.ModemManager
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{?systemd_requires}

%description
DBus interface for modem handling. Provides a standard abstracted API
(over DBus) to communicate with all sorts of modems (landline, GSM,
CDMA).

%package -n libmm-glib0
Summary:        DBus interface for modem handling -- GLib bindings
Group:          System/Libraries

%description -n libmm-glib0
DBus interface for modem handling. Provides a standard abstracted API
(over DBus) to communicate with all sorts of modems (landline, GSM,
CDMA).

%package -n typelib-1_0-ModemManager-1_0
Summary:        DBus interface for modem handling -- GLib bindings
Group:          System/Libraries

%description -n typelib-1_0-ModemManager-1_0
DBus interface for modem handling. Provides a standard abstracted API
(over DBus) to communicate with all sorts of modems (landline, GSM,
CDMA).

%package devel
Summary:        DBus interface for modem handling -- Development Files
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       libmm-glib0 = %{version}
Requires:       typelib-1_0-ModemManager-1_0 = %{version}

%description devel
DBus interface for modem handling. Provides a standard abstracted API
(over DBus) to communicate with all sorts of modems (landline, GSM,
CDMA).

%lang_package

%prep
%setup -q
%patch0 -p1

%build
pppddir=`ls -1d %{_libdir}/pppd/2*`
test -n "$pppddir" || exit 1
%configure \
    --disable-static \
    --with-polkit \
    --with-udev-base-dir=%{_udevdir} --with-qmi \
    --with-mbim
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
find %{buildroot} -type f -name "*.la" -delete -print
# create suse-specific rcFOO link
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcModemManager
%find_lang ModemManager %{name}.lang

%pre
%service_add_pre ModemManager.service

%post
%icon_theme_cache_post
%{?udev_rules_update:%udev_rules_update}
%service_add_post ModemManager.service
systemctl --quiet enable ModemManager.service || :

%preun
%service_del_preun ModemManager.service

%postun
%icon_theme_cache_postun
%service_del_postun ModemManager.service

%post -n libmm-glib0 -p /sbin/ldconfig

%postun -n libmm-glib0 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc COPYING AUTHORS README
%{_bindir}/mmcli
%{_sbindir}/ModemManager
%{_sbindir}/rcModemManager
%config %{_sysconfdir}/dbus-1/system.d/org.freedesktop.ModemManager1.conf
%{_libdir}/ModemManager/
%{_datadir}/dbus-1/interfaces/*.xml
%{_datadir}/dbus-1/system-services/org.freedesktop.ModemManager1.service
%{_datadir}/icons/hicolor/*/*/ModemManager.png
%{_datadir}/polkit-1/actions/org.freedesktop.ModemManager1.policy
%{_udevdir}/rules.d/*-mm-*.rules
%{_unitdir}/ModemManager.service
%{_mandir}/man8/mmcli.8%{?ext_man}
%{_mandir}/man8/ModemManager.8%{?ext_man}

%files lang -f %{name}.lang
%defattr(-,root,root)

%files -n libmm-glib0
%defattr(-,root,root)
%{_libdir}/libmm-glib.so.*

%files -n typelib-1_0-ModemManager-1_0
%defattr(-,root,root)
%{_libdir}/girepository-1.0/ModemManager-1.0.typelib

%files devel
%defattr(-,root,root)
%{_datadir}/gir-1.0/ModemManager-1.0.gir
%{_datadir}/vala/vapi/
%{_includedir}/ModemManager/
%{_includedir}/libmm-glib/
%{_libdir}/libmm-glib.so
%{_libdir}/pkgconfig/ModemManager.pc
%{_libdir}/pkgconfig/mm-glib.pc

%changelog
* Fri Aug 26 2016 sckang@suse.com
- Drop
  bnc878066-serial-ports-on-the-IO-card-are-not-responding.patch:
  No longer needed.
* Thu Apr 14 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
- Rebased
  bnc878066-serial-ports-on-the-IO-card-are-not-responding.patch.
* Wed Apr 13 2016 mgorse@suse.com
- Added bnc878066-serial-ports-on-the-IO-card-are-not-responding.patch
  Fixed bnc#878066:
  4810-350 (Jaspar) and 4800-783 (Keystone Hi) serial ports on the IO card are not responding
  Patch by Roy Ley Mu <rlmu@suse.com>
* Mon Apr 11 2016 dimstar@opensuse.org
- Update to version 1.4.14:
  + Core:
  - Improved several AT response parsers (+CREG, +CGDCONT,
    +CPMS...).
  - Explicitly disconnect bearer before removing it.
  + 3GPP: allow LAC/CID updates while registering.
  + QMI:
  - Don't assume LAC/CID updates are always given in system
    indications.
  - Don't add APN auth settings if user/pass not given.
  - Load SIM operator id and name with "NAS home network"
  - Power-cycle reset functionality implemented.
  + Telit:
  - Added udev rules for Telite LE910 V2.
  - Implemented modem reset & power down.
  - Implemented unlock retries loading.
  - Implemented supported/current bands loading/setting.
  - Implemented supported/current modes loading/setting.
  - Ignored proxmark3.
  + Some other minor fixes.
* Mon Nov  2 2015 zaitor@opensuse.org
- Update to version 1.4.12:
  + MBM:
  - Implemented GPS support for Ericsson modems.
  - Enabled GPS port for H5321gw and HS2350.
  + Telit:
  - Added udev rules for HE910/UE910/UL865.
  - Implemented dynamic port identification.
  + QMI:
  - Expose IP config details in bearer object even if DHCP is
    requested.
  - Retrieve MM_MODEM_3GPP_FACILITY_SIM.
  + MBIM: CDMA capabilities disabled by default (not yet
    supported).
  + libmm-glib:
  - If empty path (/) given, no SIM object will be created.
  - Added missing introspection annotations to disconnect().
  + Core:
  - Don't check the cache when explicitly asking for required
    unlocks.
  - Initialize SMS messaging support also in the secondary port.
  - New +CGMR parser which covers the Telit HE910 specific
    format.
  - New AT-based generic implementation for the Time interface.
  - Fix reporting DENIED state in 3GPP modems.
  + Policy: remove rule which was preventing us from receiving
    signals.
  + Blacklist: ignored MediaTek preloader.
  + Misc. other minor fixes
* Thu Aug  6 2015 dimstar@opensuse.org
- Add explicit pkgconfig(udev) BuildRequires: we need it to define
  %%{_udevdir}.
* Fri Jul 24 2015 jweberhofer@weberhofer.at
- Update to version 1.4.10:
  + QMI: retry unlock check on 'UimUninitialized' errors.
  + QMI: fix '0' prefixed IMEI/ESN/MEID.
  + Huawei: fix secondary port unsolicited message handling.
  + Huawei: ignore ^POSEND and ^POSITION unsolicited messages.
  + Blacklist: ignore devices from Posnet Polska S.A.
  + Blacklist: ignore Palm M5xx devices.
- Cleaned up spec
* Thu Apr 23 2015 zaitor@opensuse.org
- Update to version 1.4.8:
  + Build: avoid building DBus tests with GLib 2.32.
  + ZTE: support MF700.
  + Huawei: extend ^NDISSTATQRY parser with new response formats.
  + Blacklist: ignore devices from Access Interface Solutions.
  + Core: added ModemManager --version action.
  + Some other minor fixes.
- Changes from version 1.4.6:
  + MBIM: by default use the new mbim-proxy setup.
  + Telit: new support for HE910, UE910 and UL865.
  + Location: avoid printing location info in syslog with info
    level.
  + Greylist: add Cypress USB<->RS232 adapters
  + QMI: avoid unref-ing arrays owned by the output bundles.
  + Some other minor fixes.
- Changes from version 1.4.4:
  + Use 'DMS Set FCC Authentication' if online mode fails in QMI
    modems. This change requires bumping the libqmi version to
    1.12.4, which is the stable release including the change.
  + Fix segfault when empty pdp type string is given.
  + Fix segfault when port driver is unknown.
  + Blacklist: ignore PalmOS devices driven by 'visor'
* Mon Feb  9 2015 zaitor@opensuse.org
- Update to version 1.4.2:
  + MBIM:
  - Update to handle 'Function Error' responses as per libmbim
    1.12.
  - Handle network-notified connection status messages.
  + Bluetooth: Keep track of devices as they are move across sysfs.
  + Core: case insensitive matches in the APN list.
  + ZTE: avoid using QMI in the MF60.
  + Huawei: updated port type hint strings.
  + Icera:
  - Fix no IPv6 report response.
  - Retry Icera probing several times.
  + Altair: increase AT probe command timeout.
  + Some other minor fixes.
* Mon Oct 20 2014 dimstar@opensuse.org
- Update to version 1.4.0:
  + This version comes with the following updates in the
    interfaces:
  - Updated the logic around the IP configuration properties in
    the Bearer:
    . Setting DHCP as IP method in the IPv6 settings means that
    SLAAC should be used to retrieve correct addressing and
    routing details.
    . DHCP IP method may now be combined with an explicit static
    IP address, as IPv6 SLAAC may require the link-local
    address to be present.
    . MTU is now also included in the IP configuration
    properties, if specified by the modem, and applicable to
    both DHCP and STATIC methods.
  - New 'OFF' power state, which fully switches off the modem
    device. After setting the modem in this state, no further use
    of it can be done. Currently available in Wavecom and
    Cinterion.
  - Location interface: new 'unmanaged GPS' support, which allows
    to start/stop the GPS module in the modem, while leaving the
    location information retrieval to other processes. Currently
    available in modems with independent GPS TTYs, like
    Option/HSO, Cinterion and Huawei.
  - New Test DBus interface: not to be installed, just for
    internal system tests.
  + Other notable changes include:
  - MBIM: support for ZTE and Sequans Communications modems.
  - Ericsson MBM: Support for AT-capable /dev/cdc-wdm ports.
  - Huawei: improved support for Network time retrieval.
  - Huawei: implemented GPS support.
  - Huawei: support for /dev/cdc-wdm AT ports via the new
    huawei-cdc-ncm driver.
  - Cinterion: implemented GPS support.
  - Cinterion: implemented unlock retries loading.
  - Cinterion: gather port types for multi-tty devices.
  - Cinterion: custom wait for SIM readiness after SIM-PIN
    unlock.
  - Wavecom: custom wait for SIM readiness after SIM-PIN unlock.
  - Probing: new flag to identify hotplugged devices which don't
    need full reset.
  - Tests: internal refactor of the ports handling code, allowing
    test-driven virtual ports and system tests run during
    'make check'. This new feature also comes with a new internal
    'Test' DBus interface, as well as new --test-[*] options in
    the ModemManager program.
  - and many more fixes...
- Changes from version 1.2.0:
  + Signal interface: new interface for extended signal quality
    information.
  + OMA interface: new interface to expose the Device Management
    capabilities defined by the Open Mobile Alliance.
  + Messaging interface: new 'Messages' property.
  + Modem interface: new 'Bearers' property.
  + 3GPP interface: new 'SubscriptionState' property.
  + Other notable changes include:
  - QMI: Implemented Manual CDMA activation logic.
  - QMI: Implemented 3GPP2/CDMA SMS support.
  - QMI: Added support for QMI modems in the ZTE, x22x and
    Cinterion plugins.
  - Huawei: multiple improvements and fixes for the ^NDISDUP
    support.
  - Huawei: new mode/switching logic with ^SYSCFGEX for
    LTE-capable devices.
  - Altair-LTE: set subscription state based on PCO.
  - MediaTek: new 'mtk' plugin added for MediaTek devices.
  - libmm-glib: Added GObject Introspection and Vala support.
  - and many more fixes...
- Add gobject-introspection-devel and vala BuildRequires: new build
  dependencies.
- Split new subpackage typelib-1_0-ModemManager-1_0.
- Add rcModemManager symlink.
* Wed Aug 20 2014 lnussel@suse.de
- Add ModemManager-1.0.0-systemd-activation.patch: Fix systemd dbus
  activation (bnc#892682). Systemd does not honor Alias= lines in
  install sections; that only works if the service file in question
  is actually enabled. So the dbus service file must refer to
  ModemManager.service.
* Wed Jul 23 2014 rlmu@suse.com
- Added bnc878066-serial-ports-on-the-IO-card-are-not-responding.patch
  Fixed bnc#878066:
  4810-350 (Jaspar) and 4800-783 (Keystone Hi) serial ports on the IO card are not responding
* Wed Jan 22 2014 dimstar@opensuse.org
- As we enabled pkgconfig(qmi-glib) and pkgconfig(mbim-glib)
  BuildRequires (last change), it's arguably also a good idea to
  replace --without-qmi and --without-mbim configure parameters
  with their --with-qmi and --with-mbim counterparts (and thus
  actually really enable the support).
* Sun Dec  1 2013 dimstar@opensuse.org
- Enable pkgconfig(qmi-glib) and pkgconfig(mbim-glib)
  BuildRequires, as we now have a package for it.
* Sat Nov 30 2013 crrodriguez@opensuse.org
- Run %%udev_rules_update if such macro is defined.
* Tue Sep 10 2013 dimstar@opensuse.org
- Enable the ModemManager service. In essence, it's a D-Bus
  service so enabling it in systemd only means to make it known
  and activatable (bnc#839067).
* Fri Jul 19 2013 zaitor@opensuse.org
- Update to version 1.0.0:
  + More flexible D-Bus API that accounts for the capabilities of
    modern devices.
  + Native support for Gobi and QMI-based Qualcomm devices via
    libqmi.
  + Native support for MBIM-based devices via libmbim.
  + Preliminary support for GPS-based Location Services with some
    devices.
  + More complete messaging API.
  + New libmm-glib client library.
  + New fully-featured command-line client (mmcli).
  + Systemd integration.
  + And various other changes.
- Add pkgconfig(mbim-glib) BuildRequires: new dependency (disabled
  for now).
- Stop passing --with-pppd-plugin-dir=$pppddir to configure, not
  reqcognized anymore.
- Add pkgconfig(systemd) BuildRequires, new dependency.
- Add systemd ModemManger.service to pre, preun, post and postun.
* Fri Jun 21 2013 dimstar@opensuse.org
- Update to version 0.7.991:
  + Bug fixes and improvements on the road to 0.8.0.
* Thu Jun  6 2013 denicolo@suse.com
- License update: GPL-2.0+ and GPL-3.0
  Correct license is GPL-2.0+; see COPYING file.
  The cli tool is licensed GPL-3.0+.
* Tue Apr 16 2013 dimstar@opensuse.org
- Drop rpmlintrc: the privileges are approved in Factory.
* Sat Jan 12 2013 dimstar@opensuse.org
- Update to version 0.7.990:
  + More flexible D-Bus API that accounts for the capabilities of
    modern devices.
  + Native support for Gobi and QMI-based Qualcomm devices via
    libqmi.
  + Preliminary support for GPS-based Location Services with some
    devices.
  + More complete messaging API.
  + Fully-featured command-line client (mmcli).
- Add pkgconfig(qmi-glib) BuildRequires: new dependency.
- Create new subpackage libnm-glib0.
* Tue Nov 27 2012 dimstar@opensuse.org
- Move udev rules file to the folder specified by udev.pc by
  passing --with-udev-base-dir to configure.
* Wed Aug 29 2012 dimstar@opensuse.org
- Update to version 0.6.0.0:
  + Minor bugfixes.
* Mon Aug 20 2012 dimstar@opensuse.org
- Update to version 0.5.995.0:
  + More flexible and reliable port probing and modem setup.
  + New plugin for some Cinterion modems.
  + New plugin for some Iridium satellite modems.
  + New API for modem firmware management.
  + New API for network-provided date and time.
  + New API for indicating remaining PIN/PUK unlock retries.
  + New API for indicating enabled facility locks.
  + Plugins can now suggest and IP timeout value for connection
    managers.
- Drop ModemManager-unsupported-qmi_wwan-ports.patch: fixed
  upstream.
* Mon Aug 20 2012 vuntz@opensuse.org
- Add ModemManager-unsupported-qmi_wwan-ports.patch: fix calls to
  pppd when using the qmi_wwan. Fix bnc#776520.
* Wed Mar 14 2012 vuntz@opensuse.org
- Update to version 0.5.2.0:
  + Retry sending SMS messages in PDU mode if an error occurs in
    text mode
* Sun Feb 26 2012 vuntz@opensuse.org
- Update to version 0.5.1.97:
  + Fix reading SMS messages in text mode
  + Fix communication with some Nokia phones
- Drop ModemManager-use-deprecated.patch: fixed upstream.
- Remove libtool BuildRequires and call to autoreconf: those were
  only needed for patch above.
- Remove xz BuildRequires now that it comes for free in the build
  system.
* Wed Feb 15 2012 vuntz@opensuse.org
- Move dbus xml interface files from devel subpackage to main
  subpackage: those files might be needed at runtime.
* Wed Feb  8 2012 dimstar@opensuse.org
- Add ModemManager-use-deprecated.patch: do not warn about using
  deprecated methods. This allows to build against glib >= 2.31.14.
- Add call to autoreconf in %%%%prep section, as the patch above
  touches m4 files.
* Thu Jan 19 2012 vuntz@opensuse.org
- Update to version 0.5.1.96:
  + Fixed sending SMS messages with modems that only support PDU
    mode
* Tue Jan 10 2012 vuntz@opensuse.org
- Update to version 0.5.1.95:
  + Better detection of registration state when connecting
  + Added support for more Ericsson modems
  + Many memory leak fixes
  + Ensure Gobi devices are driven by the gobi plugin
  + Added multi-part SMS message support
  + Better handling of requests when modem is disabled
  + USSD fixes for Huawei devices
  + Added support for Nokia Internet Sticks
  + Fixed quirky response handling on some Cinterion modems
  + Fixed CREG response handling on modems that include the RAC
  + Skip sending power-up command if modem is already powered up
  + Added support for Sierra Wireless devices using Icera chips
    (USB305, Lightning)
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
- Drop ModemManager-glib-2.31.patch: fixed upstream.
* Wed Nov 16 2011 vuntz@opensuse.org
- Add ModemManager-glib-2.31.patch: fix build with glib 2.31.
* Tue Nov 15 2011 dimstar@opensuse.org
- Really enable parallel build: fix typo smp_flags => smp_mflags.
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Wed Aug  3 2011 vuntz@opensuse.org
- Update to version 0.5:
  + Improvements for Samsung modems
  + Support access technology reporting for Qualcomm Gobi modems
  + Fix communication with Nokia N900 devices
  + Support multiple CDMA Rm protocols
  + Fix handling of Option access technology reporting
  + Fix handling of CDMA EVDO registration states
  + Fix problems reconnecting Ericsson F5521gw modems
  + Better handling of some Android handset modem
  + Bugs fixed: rh#583691, lp#765516, bgo#641661, bgo#652682,
    bgo#650740, bgo#652910, bgo#637327.
* Fri Jul  1 2011 vuntz@opensuse.org
- Update to version 0.4.998:
  + Handle udev 'change' events.
  + gsm:
  - set SMS storage location before enabling notifications
  - handle case of entirely empty SPN correctly
  + ussd: fix reception, network notifications, and network
    requests
  + serial: warn when open/close take longer than 7 seconds
  + Add a DBus interface for setting the log level.
  + Add support for Samsung Y3400.
  + Improvements for Icera-based modems.
  + Improve disabling of Samsung GSM modems.
  + Fix leaks.
* Wed Jun 15 2011 dimstar@opensuse.org
- Update to version 0.4.997:
  + Add support for various Linktop devices (LW273, etc)
  + Implement standard D-Bus Properties interface PropertiesChanged
    signal
  + Add support for Qualcomm SMD-connected modems
  + Export modem state over D-Bus
  + Add D-Bus API for CDMA modem activation
  + Correctly report HSPA+ access technology
  + Correctly report home vs. roaming state with basic Sprint CDMA
    modems
  + Add D-Bus API for power-cycling/resetting modems
  + Add support for USSD responses
  + Finer grained and more consistent logging
  + Blacklist more usb-serial dongles unlikely to be modems
  + Add support for platform serial ports
  + Loosen permissions for reading device information
  + Add support for Samsung Y3300 Icera-based modem
  + Speed up probing process when ports support AT commands
  + Better SMS reception and reporting
  + Add support for some Wavecom modems
  + Add support for Simtech-based Prolink PH-300
  + Add support for Alcatel X200
  + Fix various crashes when modem is removed
  + Bigs fixed: bgo#636040, bgo#636438, bgo#637140, bgo#638038,
    bnc#674022, kde#266807, lp#673457, rh#544121.
* Thu May  5 2011 vuntz@opensuse.org
- Update to version 0.4.996:
  - Add a mechanism to get remaining incorrect PIN attempts
  - Add a mechanism to retrieve the equipment identifier
    (MEID/ESN, IMEI)
  - Added support for returning devices to factory settings
  - Better compatibility with Blackberry GSM devices
  - Added a Location Services API with support for GSM devices
  - Fixes for Novatel CDMA devices (home/roaming status, better
    signal quality reporting)
  - Better detection of EVDO registration when device is in 1X mode
  - Add support for newer Alcatel devices like X220D
  - Support for more ZTE devices
  - Fix modem detection failures with some Sierra devices
  - Add support for newer Ericsson devices
  - Add an SIM identifier for use when auto-unlocking modems
  - Add an device identifier for use when MEID/IMEI is not yet
    available
  - Handle signal quality reporting for GSM modems that don't
    support AT+CSQ
  - Add preliminary USSD support
  - Fix reconnection attempts with some Sierra devices
  - Add support for pseudo-ethernet interface on newer Sierra
    devices
  + Fixed bugs: rh#597296, rh#583691, rh#597088, bgo#626421,
    rh#585394, bgo#628105, bgo#627935, bgo#621815, rh#632516,
    lp#682282, bgo#590798
- Drop ModemManager-fix-new-glib.patch: fixed upstream.
- Drop ModemManager-polkit-deprecated.patch: fixed upstream.
- Create a devel subpackage for new development files.
* Sun Feb 13 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Add hicolor-icon-theme BuildRequires and Requires since we need
  to have those macros defined and we install hicolor icons, so we
  need to have the theme installed.
* Wed Nov 10 2010 coolo@novell.com
- Remove zero-size files from documentation.
* Wed Nov 10 2010 coolo@novell.com
- Own parent directories.
* Fri Aug 27 2010 vuntz@opensuse.org
- Add ModemManager-polkit-deprecated.patch to fix build with a
  recent polkit (>= 0.97). This is only needed on openSUSE 11.4 and
  later.
* Mon Aug  9 2010 vuntz@opensuse.org
- Add ModemManager-fix-new-glib.patch to fix build with recent
  glib.
- Build PolicyKit support: add polkit-devel BuildRequires and pass
  - -with-polkit to configure.
- Do not add -fno-strict-aliasing to CFLAGS: this is not needed
  anymore.
* Mon Jul 26 2010 dimstar@opensuse.org
- Update to version 0.4:
  + For the full list of changes, see
    http://cgit.freedesktop.org/ModemManager/ModemManager/log/?id=0.4
  + bgo#604551: add an unlockRequired property that provides lock
    status, check modem PIN state before exporting it
  + bgo#608668: tag ChineBird PL68 ports
  + bgo#591047: only set auto registration if the modem isn't idle
  + bgo#608022: allow blacklisting various devices
  + bgo#617873: gsm: be more lenient in +CGDCONT parsing
  + rh#553199: ignore CSS on EVD0-capable modems.
  + rh#573510: assume +CPIN "READY" response indicates GSM
    capability
  + rh#579247: fix sypport check for last plugin
  + rh#569067: cdma: fix subclass registration state checking in
    error paths
  + rh#571921: cdma: prevent crash on modem removal
  + rh#587400: gsm/cdma: fix data port assignment
  + Updated translations.
* Wed May 26 2010 vuntz@opensuse.org
- Remove hal-devel BuildRequires again.
- Remove ozerocdoff Recommends: usb_modeswitch is the modern
  solution, and it's already recommended. And ozerocdoff depends on
  hal, which is bad.
* Thu Jan 21 2010 tambet@novell.com
- Upgrade to version 0.3. No new features, but includes a lot of
  bug fixes and much broader hardware support.
* Thu Dec 10 2009 aj@suse.de
- Remove unused BuildRequires hal-devel
- Add build require on udev for directory ownership.
* Tue Aug 11 2009 tittiatcoke@gmail.com
- Update to the latest upstream:
  + Move device probing and detection to udev
  + Add plugin for Motorola C-series phones and BUSlink scwi275u
  + Add plugin for Qualcomm Gobi devices
  + Updated Ericsson 'mbm' driver
  + Better Huawei detection; don't drop BUSlink responses
  + Several other fixes
* Tue Jun 16 2009 tambet@novell.com
- Update to the latest upstream:
  + Some fixes to the public API to correctly implement the spec.
  + Implement unsolicited registration for modems that support it.
  + Implement new "Simple" interface.
  + Implement cached commands.
  + Implement 'V1 E1' parser to work with modems which refuse to
    turn their echo off.
  + Implement Nokia plugin.
  + Implement a plugin for ZTE modems.
  + Lots of minor bug fixes.
* Thu Feb 26 2009 tambet@novell.com
- Probe HSO modems, don't trust (often incorrect) HAL modem
  properties (bnc #468329).
* Fri Feb  6 2009 tambet@novell.com
- Fix dbus permissions (bnc #468384).
* Mon Jan 26 2009 tambet@novell.com
- Implement Novatel plugin (bnc #468323).
* Fri Jan 16 2009 tambet@novell.com
- Check the registration state even after unsuccessful attempt,
  some cards report error if they're already registered before
  the attempt (bnc #430673).
* Tue Jan  6 2009 tambet@novell.com
- Broaden the network device matching for HSO modems as some
  (newer?) modems have only matching grandparent between serial
  and ethernet device UDIs. Fix the Option driver to not steal
  HSO modems. (bnc #462534).
- Explicitly disable unsolicitied messages for generic GSM modems
  (bnc #462536).
- Not all serial devices have carrier detection. Add a property to
  the serial base class to turn it off and make certain Huawei
  modems turn it off (bnc #462567).
- Suggest "ozerocdoff" (part of bnc #405178).
* Wed Dec  3 2008 tambet@novell.com
- Fix the HSO modem plugin (bnc #449992).
- Provide 'org.freedesktop.ModemManager' so that NetworkManager
  could use alternative implementations.
* Mon Nov 24 2008 tambet@suse.de
- Always log which modem plugin is used.
* Tue Nov 18 2008 tambet@suse.de
- Don't require CDMA modems to implement verbose error reporting
  (+CMEE command) (bnc #430502).
- Add a Sierra Wireless plugin that waits a bit after enabling the
  radio (bnc #430673).
* Fri Nov  7 2008 tambet@suse.de
- Implement a plugin for Option devices.
- Enable/disable plugging with SIGUSR1.
- Recommend usb_modeswitch (bnc #442515).
* Fri Oct 24 2008 tambet@suse.de
- Add support for MBM modems.
- Use only one serial port for Huawei modems.
* Mon Oct 20 2008 tambet@suse.de
- Fix a segfault which occured when scanning results could not be
  parsed.
- Register a correct response parser for generic CDMA
  implementation.
* Fri Sep 19 2008 tambet@suse.de
- Make it build for openSUSE 11.0 as well.
- Update from upstream:
  + Implement smarter APN choosing.
  + Implement PIN changing and enabling/disabling.
  + Make sure the device is enabled before trying to send commands to it.
  + Disconnect modem if it's connected while disabling.
  + Fix the loadable module name checking.
  + Document DBus error codes and messages.
  + Get the monitoring device from HAL for Huawei modems.
  + Add correct message to mobile (+CMEE) errors.
  + Finish the non-verbose (V0) mode parser.
  + Reduce the amount of power used to minimum when modem is disabled.
  + Reset the CID when the modem is enabled/disabled and disconnected.
  + Specify call mode in the modem init string.
* Fri Sep 12 2008 tambet@suse.de
- Remove the patch to not require dbus-glib-0.75, factory has it.
- Update from upstream:
  + Rewrite the serial port handling.
  + Implement serial command queueing.
  + Define and implement error reporting.
  + Fix device added and removed signals.
* Sun Sep  7 2008 schwab@suse.de
- Use autoreconf -fi.
* Mon Sep  1 2008 tambet@suse.de
- Update from upstream:
  + Fix upper case inconsistency in the public API (SetApn).
  + Fix HSO modem plugin.
  + Implement reading IMEI, IMSI, manufacturer, model, and version (revision).
  + License ModemManager with GNU Lesser General Public License, version 2.1.
* Fri Aug 29 2008 tambet@suse.de
- Update from upstream to get the API redesign agreed on NetworkManager
  mailing list.
* Thu Aug 28 2008 tambet@suse.de
- Initial checkin for autobuild.
